@@ -14,4 +14,7 @@ class ma_part_b_taxable_income(Variable):
         part_b_deductions = tax_unit(
             "ma_part_b_taxable_income_deductions", period
         )
-        return max_(0, part_b_agi - part_b_deductions)
+        part_b_exemptions = tax_unit(
+            "ma_part_b_taxable_income_exemptions", period
+        )
+        return max_(0, part_b_agi - part_b_deductions - part_b_exemptions)
